@@ -32,8 +32,9 @@
 #' This function gives users access to the \link[lidR:LAScatalog-class]{LAScatalog} processing engine.
 #' It allows the application of a user-defined routine over an entire catalog. The LAScatalog
 #' processing engine tool is explained in the \link[lidR:LAScatalog-class]{LAScatalog class}\cr\cr
-#' This function is the core of the lidR package. It drives every single function that can process a
-#' \code{LAScatalog}. It is flexible and powerful but also complex.\cr\cr
+#' \code{catalog_apply} is the core of the lidR package. It drives every single function that can process a
+#' \code{LAScatalog}. It is flexible and powerful but also complex. \code{catalog_sapply} is the same
+#' with the option \code{automerge = TRUE} enforced to simplify the output.\cr\cr
 #' \strong{Warning:} the LAScatalog processing engine has a mechanism to load buffered data 'on-the-fly'
 #' to avoid edge artifacts, but no mechanism to remove the buffer after applying user-defined functions,
 #' since this task is specific to each process. In other \code{lidR} functions this task is performed
@@ -271,6 +272,18 @@ catalog_apply <- function(ctg, FUN, ..., .options = NULL)
   return(output)
 }
 
+#' @export
+#' @rdname catalog_apply
+catalog_sapply <- function(ctg, FUN, ..., .options = NULL)
+{
+  if (is.null(.options))
+    .options <- list(automerge = TRUE)
+  else
+    .options$automerge <- TRUE
+
+  return(catalog_apply(ctg, FUN, ..., .options = .options))
+}
+
 assert_fun_is_null_with_empty_cluster = function(ctg, FUN, ...)
 {
   if (opt_wall_to_wall(ctg) == TRUE)
