@@ -46,7 +46,7 @@ IntegerMatrix C_dalponte2016(NumericMatrix Image, IntegerMatrix Seeds, double th
   std::vector<Pixeld> neighbours(4);
 
   if (Seeds.nrow() != nrow || Seeds.ncol() != ncol)
-    throw std::runtime_error(std::string("Error: unexpected internal error: different matrix sizes."));
+    throw std::runtime_error(std::string("Error: unexpected internal error: different matrix sizes.")); // # nocov
 
 
   IntegerMatrix Region     = clone(Seeds);
